<?php

namespace App\Entity;

use App\Repository\OutputRecipeMaterialRepository;
use Doctrine\ORM\Mapping as ORM;
use Symfony\Bridge\Doctrine\Validator\Constraints\UniqueEntity;
use Symfony\Component\Validator\Constraints as Assert;

/**
 * A material produced by a recipe
 */
#[ORM\Entity(repositoryClass: OutputRecipeMaterialRepository::class)]
#[UniqueEntity(fields: ['recipe', 'material'], message: 'Ce matériau est déjà produite par cette recette')]
class OutputRecipeMaterial {
    use TBaseEntity;

    /**
     * @var Recipe|null The recipe
     */
    #[ORM\ManyToOne(inversedBy: 'outputMaterials')]
    #[ORM\JoinColumn(nullable: false, onDelete: 'CASCADE')]
    #[Assert\NotNull(message: 'Veuillez sélectionner une recette')]
    #[Assert\Valid]
    private ?Recipe $recipe = null;
    /**
     * @var Material|null The material
     */
    #[ORM\ManyToOne(inversedBy: 'recipes')]
    #[ORM\JoinColumn(nullable: false)]
    #[Assert\NotNull(message: 'Veuillez sélectionner un matériau')]
    #[Assert\Valid]
    private ?Material $material = null;

    /**
     * @var float|null The produced quantity
     */
    #[ORM\Column]
    #[Assert\Type(type: 'float', message: 'La quantité produite doit être un nombre réel')]
    #[Assert\NotNull(message: 'Veuillez saisir une quantité produite')]
    #[Assert\Positive(message: 'La quantité produite doit être strictement positive')]
    private ?float $producedQuantity = null;

    /**
     * The recipe
     *
     * @return Recipe|null The recipe
     */
    public function getRecipe (): ?Recipe {
        return $this->recipe;
    }
    /**
     * Set the recipe
     *
     * @param Recipe|null $recipe The recipe
     *
     * @return $this
     */
    public function setRecipe (?Recipe $recipe): static {
        $this->recipe = $recipe;

        return $this;
    }

    /**
     * The material
     *
     * @return Material|null The material
     */
    public function getMaterial (): ?Material {
        return $this->material;
    }
    /**
     * Set the material
     *
     * @param Material|null $material The material
     *
     * @return $this
     */
    public function setMaterial (?Material $material): static {
        $this->material = $material;

        return $this;
    }

    /**
     * The produced quantity
     *
     * @return float|null The produced quantity
     */
    public function getProducedQuantity (): ?float {
        return $this->producedQuantity;
    }
    /**
     * Set the produced quantity
     *
     * @param float $producedQuantity The produced quantity
     *
     * @return $this
     */
    public function setProducedQuantity (float $producedQuantity): static {
        $this->producedQuantity = $producedQuantity;

        return $this;
    }
}
